@@ -37,6 +37,9 @@
  * @def   APP_DSC
  * @brief Application description
  *
+ * @def   STATUS_CONFIG
+ * @brief Prefix for statusbar config file info
+ *
  * @def   DEFAULT_BG_CMD
  * @brief Default command to set wallpapers
  *
@@ -56,9 +59,10 @@
  * @brief Default setting for random wallpaper change
  */
 #define APP_NAME             "Wall Changer"
-#define APP_VER              "1.4.2"
+#define APP_VER              "1.4.3"
 #define APP_WEB              "https://www.nongnu.org/wallchanger/"
 #define APP_DSC              "Wall Changer is an automatic wallpaper changer."
+#define STATUS_CONFIG        "Config file in use: "
 #define DEFAULT_BG_CMD       "feh --bg-fill"
 #define DEFAULT_WIN_WIDTH     1024
 #define DEFAULT_WIN_HEIGHT    768
